#
# spec file for package python-humanize
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
%global modname humanize
Name:           python-humanize
Version:        4.11.0
Release:        1.1
Summary:        Python humanize utilities
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/python-humanize/humanize
Source:         https://files.pythonhosted.org/packages/source/h/humanize/humanize-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module coverage}
BuildRequires:  %{python_module hatch_vcs}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This modest package contains various common humanization utilities, like turning
a number into a fuzzy human readable duration ('3 minutes ago') or into a human
readable size or throughput.

%prep
%setup -q -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENCE
%doc README.md
%{python_sitelib}/*
%{python_sitelib}/humanize/locale/*

%changelog
* Wed Oct  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 4.11.0
  * Add natural_list (#110) @akshaybabloo
  * filesize: support the ronna and quetta prefixes (#142) @bbolli
  * Update French translations for numbers (#192) @enlivn
  * Drop support for Python 3.8 (#202) @hugovk
  * Defer fractions.Fraction import to save 5ms (#201) @hugovk
  * Speedup x 1.85: Generate __version__ at build to avoid slow
    importlib.metadata import (#200) @hugovk
  * Fix finding location of translations (#204) @dangillet
  * Fix rollover from ZB to 1.0 YB (#206) @hugovk
  * Fix zh_CN/zh_HK translation for "1 year, %%d days" (#196) @luliangce
* Wed Sep  4 2024 Frantisek Simorda <frantisek.simorda@suse.com>
- update to 4.10.0:
  * Remove shebang from filesize.py (#188)
  * Fix test failures on systems with 32-bit time_t (#177)
  * Fix handling of negative time deltas (#173)
  * Fix naturaldelta sub second precision (#169)
  * Reword the French translation of very small amount of time (#162)
  * Fix Arabic localization (#160)
  * metric: Fix precision format (#159)
* Mon Nov 27 2023 Dirk Müller <dmueller@suse.com>
- update to 4.9.0:
  * Add support for Python 3.13 (#156) @hugovk
  * Add Norwegian localization (#155) @fdanielsen
  * Add Hebrew localization (#149) @clsn
  * Add Klingon translation (#150) @clsn
  * Replace Flake8 with Ruff (#157) @hugovk
  * Fix DeprecationWarning: Plural value must be an integer, got
    float (#147) @dansarpong
  * Remove useless shebangs (#141) @aueam
* Wed Sep 13 2023 Dirk Müller <dmueller@suse.com>
- update to 4.8.0:
  * Add Hungarian localization
  * Revise Turkish localization
  * Translate "thousand" to "千" for zh_CN
  * Move logic to convert aware datetime to naive into function
  * Docs: fix formatting of return value
  * Declare support for Python 3.12
  * Add Esperanto localization
  * Support timezone-aware datetimes in naturaltime
  * Update Bengali translation
  * Drop support for EOL Python 3.7
  * Add missing keys to extract translatable strings
  * Add default Italian thousand and decimal separator
  * Add Italian translation for "thousand" and fix singulars
  * Add Italian translation for "%%s and %%s"
  * Add Basque translation
  * Add latest metric prefixes: ronna, ronto, quetta, quecto
  * Add pt_BR separators
  * Replace setup.cfg with pyproject.toml
  * Filesize simplification
  * Fix intword for 1,000 decillion
  * Add localisation for thousand, fixing German plurals
  * Handle NaN
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 4.4.0:
  * Add installation instructions (#56) @hugovk
  * Internationalise the decimal separator in intcomma() (#53) @Luflosi
  * Internationalise intcomma for de_DE locale (#49) @Luflosi
  * Replace short scale with long scale for Polish numbers (#54) @mjmikulski
  * Fix intcomma() failing with a string as input when ndigits is not None
    (#52) @Luflosi
  * Fix some pylint findings (#42) @hugovk
  * Fix "ValueError: math domain error" for metric(0) (#47) @liukun
  * Add Greek translation (#46) @waseigo
  * Polish: Added thousand, fixed big numbers (#43) @dejurin
  * Fix intword for negative numbers (#41) @vishket
  * Update annotations, docs, and tests: naturaltime can also accept a
    timedelta (#31) @nuztalgia
  * Update annotations: naturadelta and naturaltime can also accept a float
    (#29) @hugovk
  * Rename Arabic locale from ar_SA to ar to enable fallbacks (#27) @hugovk
  * Use %%d for year translations, convert to string for intcomma after (#23)
    @carterbox
  * Fix intcomma with ndigits=0 (#26) @hugovk
  * Add humanize.metric() for converting big/small numbers to SI units (#22)
  * Add type hints (#15) @hugovk
  * Fix scientific() on small positive numbers (#22) @bwoodsend
  * Remove redundant wheel dependency from pyproject.toml (#16) @mgorny
  * Support Python 3.11 (#13) @hugovk
  * Add Arabic language (jmoiron/humanize#256) @AYMENJD
  * Docs: add dark mode toggle and default to system preference
    (jmoiron/humanize#255) @hugovk
  * Documentation improvements (jmoiron/humanize#254) @mondeja
  * Update repo links (#2) @hugovk
* Thu Oct 13 2022 Dirk Müller <dmueller@suse.com>
- use https for urls
* Tue Mar  8 2022 Edgar Aichinger <edogawa@aon.at>
- update to 4.0.0:
  * Drop support for Python 3.6
  * Remove deprecated VERSION, use version instead
  * Remove when from naturaldelta() and allow largest timedelta
  * Remove deprecated private function aliases
* Mon Sep 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 2.6.0:
  * Deploy docs to Read the Docs (#148) @hugovk
  * Build API reference docs from docstrings using MKDocs (#147) @hugovk
  * Function to represent timedeltas without losing precision (precisedelta) (#137) @eldipa
  * Improve default locale path discovering. (#146) @mondeja
  * Added Ukrainian language to list in README.md (#141) @tuxlabore
* Thu Jun  4 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.4.0:
  * Added Spanish (Spain) locale.
  * Polish (pl_PL) locales added
- Switch to %%pytest macro.
* Tue Mar 31 2020 steven.kowalik@suse.com
- Update to 2.2.0:
  * Added
    + Disambiguate naturaldate return: only append year if more than
    + ~5 months away (#107) @hugovk
    + Add scientific notation to string support (#110) @Thx3r @hugovk
    + Add micro- and millisecond units to naturaldelta and
    + naturaltime (#104) @hugovk
    + Add ndigits option to intcomma (#123) @hugovk
    + Show more than bytes for negative file sizes (#122) @hugovk
  * Fixed
    + Fix: AP style for 0 is 'zero' (#121) @hugovk
  * Changed
    + Disambiguate naturaldate return: only append year if more than ~5 months away (#107) @hugovk
    + Convert remaining tests to use pytest.mark.parametrize (#109) @hugovk
    + Refactor some tests to use pytest.mark.parametrize (#108) @hugovk
  * Removed
    + Drop support for EOL Python 2 (#102) @hugovk
- Fiddle with BuildRequires, adding new modules that are needed
- Switch to pypi source tarball, required for setuptools_scm
* Wed Jun  5 2019 Petr Gajdos <pgajdos@suse.com>
- test package in %%check
* Mon Dec 10 2018 Tomáš Chvátal <tchvatal@suse.com>
- Fix fdupes call
- Fix Source url
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Jul  1 2017 okurz@suse.com
- Convert to singlespec
* Fri Dec 18 2015 mimi.vx@gmail.com
- update to 0.5.1
- use %%find_lang macro
* Sun Dec  8 2013 p.drouand@gmail.com
- Update to version 0.5
  + No changelog available
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Mon Jul 23 2012 saschpe@suse.de
- Initial version
